@@ -1,4 +1,6 @@
 ##
+#' Cohen's d calculation
+#'
 #' @title Cohen's d
 #'
 #' @description Calculate Conhen's d
@@ -10,8 +12,7 @@
 #'
 #' @export
 #' @return numeric Cohen's d calculation
-##
-cohens.d <- function(x, y) {
+fun_cohens.d <- function(x, y) {
   lx <- length(x)- 1
   ly <- length(y)- 1
   md  <- abs(mean(x) - mean(y))        ## mean difference (numerator)
